@@ -26,6 +26,7 @@ from semantic_release.enums import LevelBump
 from semantic_release.errors import (
     BuildDistributionsError,
     GitCommitEmptyIndexError,
+    InternalError,
     UnexpectedResponse,
 )
 from semantic_release.gitproject import GitProject
@@ -35,16 +36,16 @@ from semantic_release.version.algorithm import (
     tags_and_versions,
 )
 from semantic_release.version.translator import VersionTranslator
-from semantic_release.version.version import Version
 
 if TYPE_CHECKING:  # pragma: no cover
     from pathlib import Path
-    from typing import Iterable, Mapping
+    from typing import Mapping, Sequence
 
     from git.refs.tag import Tag
 
     from semantic_release.cli.cli_context import CliContextObj
-    from semantic_release.version.declaration import VersionDeclarationABC
+    from semantic_release.version.declaration import IVersionReplacer
+    from semantic_release.version.version import Version
 
 
 log = logging.getLogger(__name__)
@@ -64,7 +65,7 @@ def is_forced_prerelease(
     log.debug(
         "%s: %s",
         is_forced_prerelease.__name__,
-        ", ".join(f"{k} = {v}" for k, v in local_vars),
+        str.join(", ", iter(f"{k} = {v}" for k, v in local_vars)),
     )
     return (
         as_prerelease
@@ -90,7 +91,18 @@ def version_from_forced_level(
 
     # If we have no tags, return the default version
     if not ts_and_vs:
-        return Version.parse(DEFAULT_VERSION).bump(forced_level_bump)
+        # Since the translator is configured by the user, we can't guarantee that it will
+        # be able to parse the default version. So we first cast it to a tag using the default
+        # value and the users configured tag format, then parse it back to a version object
+        default_initial_version = translator.from_tag(
+            translator.str_to_tag(DEFAULT_VERSION)
+        )
+        if default_initial_version is None:
+            # This should never happen, but if it does, it's a bug
+            raise InternalError(
+                "Translator was unable to parse the embedded default version"
+            )
+        return default_initial_version.bump(forced_level_bump)
 
     _, latest_version = ts_and_vs[0]
     if forced_level_bump is not LevelBump.PRERELEASE_REVISION:
@@ -123,28 +135,43 @@ def version_from_forced_level(
 
 def apply_version_to_source_files(
     repo_dir: Path,
-    version_declarations: Iterable[VersionDeclarationABC],
+    version_declarations: Sequence[IVersionReplacer],
     version: Version,
     noop: bool = False,
 ) -> list[str]:
-    paths = [
-        str(declaration.path.resolve().relative_to(repo_dir))
-        for declaration in version_declarations
+    if len(version_declarations) < 1:
+        return []
+
+    if not noop:
+        log.debug("Updating version %s in repository files...", version)
+
+    paths = list(
+        map(
+            lambda decl, new_version=version, noop=noop: (  # type: ignore[misc]
+                decl.update_file_w_version(new_version=new_version, noop=noop)
+            ),
+            version_declarations,
+        )
+    )
+
+    repo_filepaths = [
+        str(updated_file.relative_to(repo_dir))
+        for updated_file in paths
+        if updated_file is not None
     ]
 
     if noop:
         noop_report(
-            "would have updated versions in the following paths:"
-            + "".join(f"\n    {path}" for path in paths)
+            str.join(
+                "",
+                [
+                    "would have updated versions in the following paths:",
+                    *[f"\n    {filepath}" for filepath in repo_filepaths],
+                ],
+            )
         )
-        return paths
 
-    log.debug("writing version %s to source paths %s", version, paths)
-    for declaration in version_declarations:
-        new_content = declaration.replace(new_version=version)
-        declaration.path.write_text(new_content)
-
-    return paths
+    return repo_filepaths
 
 
 def shell(
@@ -516,12 +543,8 @@ def version(  # noqa: C901
     gha_output.version = new_version
     ctx.call_on_close(gha_output.write_if_possible)
 
-    # Make string variant of version && Translate to tag if necessary
-    version_to_print = (
-        str(new_version)
-        if not print_only_tag
-        else translator.str_to_tag(str(new_version))
-    )
+    # Make string variant of version or appropriate tag as necessary
+    version_to_print = str(new_version) if not print_only_tag else new_version.as_tag()
 
     # Print the new version so that command-line output capture will work
     click.echo(version_to_print)
@@ -691,13 +714,31 @@ def version(  # noqa: C901
         log.info("Remote does not support releases. Skipping release creation...")
         return
 
+    license_cfg = runtime.project_metadata.get(
+        "license-expression",
+        runtime.project_metadata.get(
+            "license",
+            "",
+        ),
+    )
+
+    if not isinstance(license_cfg, (str, dict)) or license_cfg is None:
+        license_cfg = ""
+
+    license_name = (
+        license_cfg.get("text", "")
+        if isinstance(license_cfg, dict)
+        else license_cfg or ""
+    )
+
     release_notes = generate_release_notes(
         hvcs_client,
-        release_history.released[new_version],
-        runtime.template_dir,
+        release=release_history.released[new_version],
+        template_dir=runtime.template_dir,
         history=release_history,
         style=runtime.changelog_style,
         mask_initial_release=runtime.changelog_mask_initial_release,
+        license_name=license_name,
     )
 
     exception: Exception | None = None
