@@ -1,7 +1,6 @@
 from __future__ import annotations
 
 import os
-from importlib import import_module
 from pathlib import Path
 from textwrap import dedent
 from typing import TYPE_CHECKING, Generator
@@ -14,7 +13,7 @@ from importlib_resources import files
 
 import semantic_release
 from semantic_release.commit_parser import (
-    AngularCommitParser,
+    ConventionalCommitParser,
     EmojiCommitParser,
     ScipyCommitParser,
 )
@@ -60,7 +59,7 @@ if TYPE_CHECKING:
         def __call__(self, setting: str, value: Any) -> None: ...
 
     class UseCustomParserFn(Protocol):
-        def __call__(self, module_import_str: str) -> type[CommitParser]: ...
+        def __call__(self, module_import_str: str) -> None: ...
 
     class UseHvcsFn(Protocol):
         def __call__(self, domain: str | None = None) -> type[HvcsBase]: ...
@@ -415,7 +414,11 @@ def update_pyproject_toml(pyproject_toml_file: Path) -> UpdatePyprojectTomlFn:
             if pointer.get(part, None) is None:
                 pointer.add(part, tomlkit.table())
             pointer = pointer.get(part, {})
-        pointer.update(new_setting)
+
+        if value is None:
+            pointer.pop(new_setting_key)
+        else:
+            pointer.update(new_setting)
 
         with open(cwd_pyproject_toml, "w") as wfd:
             tomlkit.dump(pyproject_toml, wfd)
@@ -449,17 +452,17 @@ def set_allow_zero_version(update_pyproject_toml: UpdatePyprojectTomlFn) -> SetF
 
 
 @pytest.fixture(scope="session")
-def use_angular_parser(
+def use_conventional_parser(
     update_pyproject_toml: UpdatePyprojectTomlFn,
     pyproject_toml_config_option_parser: str,
 ) -> UseParserFn:
-    """Modify the configuration file to use the Angular parser."""
+    """Modify the configuration file to use the Conventional parser."""
 
-    def _use_angular_parser() -> type[CommitParser]:
-        update_pyproject_toml(pyproject_toml_config_option_parser, "angular")
-        return AngularCommitParser
+    def _use_conventional_parser() -> type[CommitParser]:
+        update_pyproject_toml(pyproject_toml_config_option_parser, "conventional")
+        return ConventionalCommitParser
 
-    return _use_angular_parser
+    return _use_conventional_parser
 
 
 @pytest.fixture(scope="session")
@@ -497,17 +500,8 @@ def use_custom_parser(
 ) -> UseCustomParserFn:
     """Modify the configuration file to use a user defined string parser."""
 
-    def _use_custom_parser(module_import_str: str) -> type[CommitParser]:
-        # validate this is importable before writing to parser
-        module_name, attr = module_import_str.split(":", maxsplit=1)
-        try:
-            module = import_module(module_name)
-            custom_class = getattr(module, attr)
-        except (ModuleNotFoundError, AttributeError) as err:
-            raise ValueError("Custom parser object not found!") from err
-
+    def _use_custom_parser(module_import_str: str) -> None:
         update_pyproject_toml(pyproject_toml_config_option_parser, module_import_str)
-        return custom_class
 
     return _use_custom_parser
 
